@@ -1,6 +1,6 @@
 # _*_ coding: utf-8 _*_
 #
-# HSPyLib v0.11.5
+# HSPyLib-Core v0.11.7
 #
 # Package: main.hspylib.addons.appman
 """Package initialization."""
@@ -8,5 +8,7 @@
 __all__ = [
   'app_extension', 
   'app_type', 
-  'appman'
+  'appman', 
+  'templates'
 ]
+__version__ = '0.11.7'
