@@ -2,9 +2,8 @@
 # -*- coding: utf-8 -*-
 
 """
-   TODO Purpose of the file
    @project: HSPyLib
-   hspylib.main.hspylib.core.crud.db
+   @Package: hspylib.main.hspylib.core.crud.db
       @file: db_repository.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -39,39 +38,31 @@ class DBRepository(CrudRepository):
     @abstractmethod
     def connect(self):
         """TODO"""
-        pass
 
     @abstractmethod
     def disconnect(self):
         """TODO"""
-        pass
 
     @abstractmethod
     def is_connected(self):
         """TODO"""
-        pass
 
     @abstractmethod
     def execute(self, sql_statement: str, auto_commit: bool, *params):
         """TODO"""
-        pass
 
     @abstractmethod
     def commit(self):
         """TODO"""
-        pass
 
     @abstractmethod
     def rollback(self):
         """TODO"""
-        pass
 
     @abstractmethod
     def row_to_entity(self, row: Tuple) -> CrudEntity:
         """TODO"""
-        pass
 
     @abstractmethod
     def table_name(self) -> str:
         """TODO"""
-        pass
