@@ -2,9 +2,8 @@
 # -*- coding: utf-8 -*-
 
 """
-   TODO Purpose of the file
    @project: HSPyLib
-   hspylib.main.hspylib.core.tools
+   @package: hspylib.main.hspylib.core.tools
       @file: validator.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -37,38 +36,38 @@ class Validator(ABC):
 
     @staticmethod
     def matches(
-            input_string: str,
-            regex_pattern: str) -> bool:
+        input_string: str,
+        regex_pattern: str) -> bool:
 
         return bool(re.match(regex_pattern, input_string))
 
     @staticmethod
     def is_integer(
-            number: str,
-            min_value: int = 0,
-            max_value: int = 65535) -> bool:
+        number: str,
+        min_value: int = 0,
+        max_value: int = 65535) -> bool:
 
         return number.isdigit() and min_value <= int(number) <= max_value
 
     @staticmethod
     def is_float(
-            number: str,
-            min_value: float = 0,
-            max_value: float = 65535) -> bool:
+        number: str,
+        min_value: float = 0,
+        max_value: float = 65535) -> bool:
 
         return number.isdecimal() and min_value <= float(number) <= max_value
 
     @staticmethod
     def is_enum(
-            name: str,
-            enum_type: Type) -> bool:
+        name: str,
+        enum_type: Type) -> bool:
 
         return name.upper() in enum_type.__dict__
 
     @staticmethod
     def is_date(
-            date_text: str,
-            fmt: str = DATE_TIME_FORMAT) -> bool:
+        date_text: str,
+        fmt: str = DATE_TIME_FORMAT) -> bool:
 
         try:
             datetime.strptime(date_text, fmt)
@@ -80,6 +79,13 @@ class Validator(ABC):
     def has_no_nulls(*args) -> bool:
         return all(opt is not None for opt in args)
 
+    @staticmethod
+    def in_range(array: list, start: int, end: int) -> bool:
+        return \
+            list is not None \
+            and 0 <= start < len(array) \
+            and 0 <= start <= end < len(array)
+
     @abstractmethod
     def __call__(self, *args, **kwargs) -> bool:
         pass
